<?php
/**
 * @file
 * Contains \Drupal\ajax_search_block\Controller\APIController.
 */

namespace Drupal\ajax_search_block\Controller;

use Drupal\Core\Controller\ControllerBase;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Datetime\DrupalDateTime;

/**
 * Controller routines for api routes.
 */
class APIController extends ControllerBase {

  /**
   * Callback for `api/get_pages` API method.
   */
  public function get_pages( Request $request ) {
  	$params = $request->query->all();
  	if(count($params) > 0 && !empty($params['t'])){
  		$response['nodes'] = $this->_get_all_nodes_and_taxonomies($params['t']);
  	}
    $response['method'] = 'GET';

    return new JsonResponse( $response );
  }

  /**
   * Callback for `api/get_alias` API method.
   */
  public function get_alias( Request $request ) {
  	$params = $request->query->all();
  	if(count($params) > 0 && !empty($params['path'])){
  		$path_alias = \Drupal::service('path.alias_manager')->getAliasByPath($params['path']);
  		$response['url'] = $path_alias;
  	}
    $response['method'] = 'GET';

    return new JsonResponse( $response );
  }

 /**
 * Implements _get_all_nodes_and_taxonomies().
 *
 * @param ($text) search text
 *
 * @return object.
 */
	function _get_all_nodes_and_taxonomies($text){
		$config = \Drupal::config('ajax_search_block.settings');
		$node_types = (!empty($config->get('node_types_selected'))) ? $config->get('node_types_selected') : null;
		$vocabulary_vids = (!empty($config->get('taxonomy_types_selected'))) ? $config->get('taxonomy_types_selected') : null;

		$query_nodes = \Drupal::database()->select('node_field_data', 'nfd');
		$query_nodes->addField('nfd', 'nid', 'drupal_id');
		$query_nodes->addField('nfd', 'title', 'result');
		$query_nodes->addExpression("concat('/node/', nid)", "path");
		$query_nodes->condition('nfd.title', '%' . db_like($text) . '%', 'LIKE');
		$query_nodes->condition('nfd.type', $node_types, 'IN');

		$query_terms = \Drupal::database()->select('taxonomy_term_field_data', 'ttfd');
		$query_terms->addField('ttfd', 'tid', 'drupal_id');
		$query_terms->addField('ttfd', 'name', 'result');
		$query_terms->addExpression("concat('/taxonomy/term/', tid)", "path");
		$query_terms->condition('ttfd.name', '%' . db_like($text) . '%', 'LIKE');
		$query_terms->condition('ttfd.vid', $vocabulary_vids, 'IN');

		$query_terms->orderBy('result');

		if( count( $node_types ) > 0 && count( $query_terms ) > 0 ){
			$query_terms->union($query_nodes, 'DISTINCT');
			$pages = $query_terms->execute()->fetchAll();
		}elseif( count( $node_types ) > 0 ){
			$pages = $query_nodes->execute()->fetchAll();
		}elseif( count( $query_terms ) > 0 ){
			$pages = $query_terms->execute()->fetchAll();
		}

		return $pages;
	}
}
